@@ -1,5 +1,9 @@
 """jc - JSON CLI output utility `dig` command output parser
 
+Options supported:
+- `+noall +answer` options are supported in cases where only the answer information is desired.
+- `+axfr` option is supported on its own
+
 The `when_epoch` calculated timestamp field is naive (i.e. based on the local time of the system the parser is run on)
 
 The `when_epoch_utc` calculated timestamp field is timezone-aware and is only available if the timezone field is UTC.
@@ -270,19 +274,55 @@ Examples:
         "rcvd": "78"
       }
     ]
+
+    $ dig +noall +answer cnn.com | jc --dig -p
+    [
+      {
+        "answer": [
+          {
+            "name": "cnn.com.",
+            "class": "IN",
+            "type": "A",
+            "ttl": 60,
+            "data": "151.101.193.67"
+          },
+          {
+            "name": "cnn.com.",
+            "class": "IN",
+            "type": "A",
+            "ttl": 60,
+            "data": "151.101.65.67"
+          },
+          {
+            "name": "cnn.com.",
+            "class": "IN",
+            "type": "A",
+            "ttl": 60,
+            "data": "151.101.1.67"
+          },
+          {
+            "name": "cnn.com.",
+            "class": "IN",
+            "type": "A",
+            "ttl": 60,
+            "data": "151.101.129.67"
+          }
+        ]
+      }
+    ]
 """
 import jc.utils
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '2.0'
+    version = '2.1'
     description = '`dig` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
 
     # compatible options: linux, darwin, cygwin, win32, aix, freebsd
-    compatible = ['linux', 'aix', 'freebsd', 'darwin']
+    compatible = ['linux', 'aix', 'freebsd', 'darwin', 'win32', 'cygwin']
     magic_commands = ['dig']
 
 
@@ -500,6 +540,7 @@ def parse(data, raw=False, quiet=False):
     # section can be: header, flags, question, authority, answer, axfr, additional, opt_pseudosection, footer
     section = ''
     output_entry = {}
+    answer_list = []
 
     if jc.utils.has_data(data):
         for line in cleandata:
@@ -581,7 +622,12 @@ def parse(data, raw=False, quiet=False):
                 output_entry.update({'authority': authority_list})
                 continue
 
-            if not line.startswith(';') and section == 'answer':
+            # https://github.com/kellyjonbrazil/jc/issues/133
+            # to allow parsing of output that only has the answer section - e.g:
+            # dig +noall +answer example.com
+            # we allow section to be 'answer' (normal output) or
+            # '', which means +noall +answer was used.
+            if not line.startswith(';') and (section == 'answer' or section == ''):
                 answer_list.append(_parse_answer(line))
                 output_entry.update({'answer': answer_list})
                 continue
