@@ -15,9 +15,14 @@ Usage (module):
     import jc.parsers.env
     result = jc.parsers.env.parse(env_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd'
+    [
+      {
+        "name":     string,
+        "value":    string
+      }
+    ]
 
 Examples:
 
@@ -63,7 +68,8 @@ import jc.utils
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`env` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -76,7 +82,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -86,14 +92,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "name":     string,
-            "value":    string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
 
     # rebuild output for added semantic information
@@ -139,4 +138,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
