@@ -13,9 +13,17 @@ Usage (module):
     import jc.parsers.systemctl
     result = jc.parsers.systemctl.parse(systemctl_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "unit":          string,
+        "load":          string,
+        "active":        string,
+        "sub":           string,
+        "description":   string
+      }
+    ]
 
 Examples:
 
@@ -49,7 +57,8 @@ import jc.utils
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`systemctl` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -62,7 +71,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -72,17 +81,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "unit":          string,
-            "load":          string,
-            "active":        string,
-            "sub":           string,
-            "description":   string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     # nothing more to process
     return proc_data
@@ -133,4 +132,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
